summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/render_messages_internal.h')
-rw-r--r--chrome/common/render_messages_internal.h14
1 files changed, 6 insertions, 8 deletions
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 4e6643c..a4098a0 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -890,8 +890,8 @@ IPC_BEGIN_MESSAGES(ViewHost, 2)
// - Notifying a renderer process moves its input focus from a
// password input to an editable control which is NOT a password
// input.
// A renderer process also has to set caret_x and caret_y and
// specify the new caret position.
// + IME_COMPLETE_COMPOSITION
// Finish the current composition.
// This code is used for notifying a renderer process moves its
@@ -899,13 +899,11 @@ IPC_BEGIN_MESSAGES(ViewHost, 2)
// which is NOT a password input. A browser process closes its IME
// windows without changing the activation status of its IME, i.e. it
// keeps activating its IME.
- // * caret_x (int)
- // * caret_y (int)
- // They specify the position of the input caret.
- IPC_MESSAGE_ROUTED3(ViewHostMsg_ImeUpdateStatus,
+ // * caret_rect (gfx::Rect)
+ // They specify the rectangle of the input caret.
+ IPC_MESSAGE_ROUTED2(ViewHostMsg_ImeUpdateStatus,
ViewHostMsg_ImeControl, /* control */
- int, /* caret_x */
- int /* caret_y */)
+ gfx::Rect /* caret_rect */)
// Response for InspectElement request. Returns the number of resources
// identified by InspectorController.
@@ -890,8 +890,8 @@ IPC_BEGIN_MESSAGES(ViewHost, 2)
// password input to an editable control which is NOT a password
// input.
- // A renderer process also has to set caret_x and caret_y and
- // specify the new caret position.
+ // A renderer process also has to set caret_rect and
+ // specify the new caret rectangle.
// + IME_COMPLETE_COMPOSITION
// Finish the current composition.